In-memory state backend โ no persistence, no external dependencies.
Suitable for sandbox deployments (Glama), integration testing, and quick prototyping where durability is not needed.
In-memory state backend โ no persistence, no external dependencies.
Suitable for sandbox deployments (Glama), integration testing, and quick prototyping where durability is not needed.